# RocketlaneApp MCP Server

An MCP Server for the RocketlaneApp API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the RocketlaneApp API.


| Tool | Description |
|------|-------------|
| `get_subscription` | Retrieves subscription details from the server. |
| `get_home` | Retrieves the JSON response from the '/home' endpoint of the configured API. |
| `get_all_projects` | Retrieves a list of all projects from the remote service. |
| `get_projects_by_projectid` | Retrieves project details for a given project ID from the server. |
| `get_projects_by_projectid_tasks` | Retrieves a list of tasks associated with a given project ID. |
| `create_task` | Creates a new task within the specified project, assigning optional details such as description, name, assignee, start date, and due date. |
